==> gnome-do-plugins_0.8.1.3+dfsg.orig.tar.gz: gnome-do-plugins-0.8.1.3/GNOME-Screenshot/src/ScreenshotDelayItem.cs <==
/* ScreenshotDelayItem.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using Mono.Unix;
using Do.Universe;

namespace GNOME
{

	class ScreenshotDelayItem : Item
	{

		public ScreenshotDelayItem (int seconds)
		{
			Seconds = seconds;
		}

		public override string Name {
			get { return string.Format (Catalog.GetString ("{0}-second delay"), Seconds); }
		}

		public override string Description {
			get {
				string waitString = Catalog.GetPluralString (
				    "Wait {0} second before taking the screenshot.",
				    "Wait {0} seconds before taking the screenshot.", Seconds);
				return string.Format (waitString, Seconds);
			}
		}

		public override string Icon {
			get { return "gnome-panel-clock"; }
		}

		public int Seconds { get; protected set;}
	}
}

==> gnome-do-plugins_0.8.5.orig.tar.gz: gnome-do-plugins-0.8.5/GNOME-Screenshot/src/ScreenshotDelayItem.cs <==
/* ScreenshotDelayItem.cs
 *
 * GNOME Do is the legal property of its developers. Please refer to the
 * COPYRIGHT file distributed with this
 * source distribution.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using Mono.Addins;
using Do.Universe;

namespace GNOME
{

	class ScreenshotDelayItem : Item
	{

		public ScreenshotDelayItem (int seconds)
		{
			Seconds = seconds;
		}

		public override string Name {
			get { return string.Format (AddinManager.CurrentLocalizer.GetString ("{0}-second delay"), Seconds); }
		}

		public override string Description {
			get {
				string waitString = AddinManager.CurrentLocalizer.GetPluralString (
				    "Wait {0} second before taking the screenshot.",
				    "Wait {0} seconds before taking the screenshot.", Seconds);
				return string.Format (waitString, Seconds);
			}
		}

		public override string Icon {
			get { return "gnome-panel-clock"; }
		}

		public int Seconds { get; protected set;}
	}
}
